@@ -1,7 +1,7 @@
 package Bencher::Scenario::CBlocks::Numeric;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-07-03'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -93,7 +93,7 @@ Bencher::Scenario::CBlocks::Numeric - Benchmark numeric performance of C::Blocks
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::CBlocks::Numeric (from Perl distribution Bencher-Scenarios-CBlocks), released on 2017-01-25.
+This document describes version 0.003 of Bencher::Scenario::CBlocks::Numeric (from Perl distribution Bencher-Scenarios-CBlocks), released on 2017-07-03.
 
 =head1 SYNOPSIS
 
@@ -210,41 +210,41 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2
 Benchmark with default options (C<< bencher -m CBlocks::Numeric >>):
 
  #table1#
- +-------------+---------+-----------+------------+------------+-----------+---------+
- | participant | dataset | rate (/s) | time (ms)  | vs_slowest |  errors   | samples |
- +-------------+---------+-----------+------------+------------+-----------+---------+
- | C::Blocks   | 316227  |       6.1 | 160        |        1   |   0.00028 |       7 |
- | perl        | 316227  |       6.8 | 150        |        1.1 |   0.00075 |       6 |
- | C::Blocks   | 100000  |      20   |  50        |        3   |   0.00089 |       7 |
- | perl        | 100000  |      20   |  50        |        3   |   0.00069 |       6 |
- | perl        | 31622   |      70   |  10        |       10   |   0.00023 |       6 |
- | C::Blocks   | 10000   |     100   |   7        |       20   |   0.00036 |      10 |
- | perl        | 10000   |     219   |   4.57     |       35.9 | 2.4e-06   |       6 |
- | C::Blocks   | 3235    |     400   |   2.5      |       66   |   2e-05   |       9 |
- | perl        | 3235    |     654   |   1.53     |      107   | 2.9e-07   |       6 |
- | C::Blocks   | 1000    |    1000   |   0.9      |      200   | 1.4e-05   |       7 |
- | perl        | 1000    |    2290   |   0.436    |      376   | 3.9e-07   |       6 |
- | C::Blocks   | 31622   |    2900   |   0.34     |      480   | 4.9e-07   |       6 |
- | C::Blocks   | 316     |    5800   |   0.17     |      950   | 8.8e-07   |       6 |
- | perl        | 316     |    7200   |   0.14     |     1200   | 2.9e-07   |      11 |
- | C::Blocks   | 100     |   18539   |   0.053939 |     3043.9 | 6.7e-11   |       6 |
- | perl        | 100     |   23000   |   0.044    |     3700   | 6.8e-08   |       7 |
- | C::Blocks   | 31      |   30000   |   0.03     |     5000   | 6.2e-07   |       9 |
- | perl        | 31      |   65330   |   0.01531  |    10730   |   5e-10   |       6 |
- | C::Blocks   | 10      |  100000   |   0.0096   |    17000   | 2.4e-08   |       6 |
- | perl        | 10      |  190000   |   0.0053   |    31000   | 1.5e-08   |       6 |
- +-------------+---------+-----------+------------+------------+-----------+---------+
+ +-------------+---------+-----------+-------------+------------+-----------+---------+
+ | participant | dataset | rate (/s) | time (ms)   | vs_slowest |  errors   | samples |
+ +-------------+---------+-----------+-------------+------------+-----------+---------+
+ | C::Blocks   | 316227  |      6.43 | 155         |       1    |   0.00014 |       6 |
+ | perl        | 316227  |      6.95 | 144         |       1.08 | 8.3e-05   |       6 |
+ | C::Blocks   | 100000  |     19.8  |  50.6       |       3.07 | 3.3e-05   |       6 |
+ | perl        | 100000  |     22.1  |  45.3       |       3.43 | 3.2e-05   |       9 |
+ | C::Blocks   | 31622   |     66.5  |  15         |      10.3  | 2.9e-06   |       6 |
+ | perl        | 31622   |     70.4  |  14.2       |      10.9  |   2e-06   |       6 |
+ | perl        | 10000   |    133    |   7.516     |      20.68 | 3.9e-07   |       6 |
+ | perl        | 3235    |    683.8  |   1.462     |     106.3  | 9.7e-08   |       6 |
+ | perl        | 1000    |   2212.87 |   0.451902  |     344    | 5.3e-11   |       6 |
+ | perl        | 316     |   6993.43 |   0.142991  |    1087.16 | 6.4e-11   |       6 |
+ | C::Blocks   | 10000   |   8480.48 |   0.117918  |    1318.33 |   0       |       6 |
+ | C::Blocks   | 100     |  20854.2  |   0.0479519 |    3241.88 |   0       |       6 |
+ | perl        | 100     |  21400    |   0.0468    |    3320    | 2.3e-08   |       7 |
+ | C::Blocks   | 3235    |  32577.3  |   0.0306962 |    5064.28 | 2.1e-11   |       6 |
+ | C::Blocks   | 31      |  65280.9  |   0.0153184 |   10148.2  |   0       |       6 |
+ | perl        | 31      |  69735.4  |   0.0143399 |   10840.7  |   0       |       6 |
+ | C::Blocks   | 1000    | 103887    |   0.0096258 |   16149.7  |   0       |       6 |
+ | C::Blocks   | 10      | 202450    |   0.0049396 |   31471    | 2.1e-11   |       6 |
+ | perl        | 10      | 210000    |   0.0047    |   33000    | 1.1e-08   |       7 |
+ | C::Blocks   | 316     | 323000    |   0.00309   |   50300    |   3e-09   |       6 |
+ +-------------+---------+-----------+-------------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m CBlocks::Numeric --module-startup >>):
 
  #table2#
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | C::Blocks           | 2.4                          | 6                  | 22             |        23 |                     17 |          1 |   0.00011 |       6 |
- | perl -e1 (baseline) | 0.8                          | 4                  | 20             |         6 |                      0 |          4 | 6.3e-05   |       7 |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | C::Blocks           | 2.4                          | 5.9                | 22             |        21 |                     16 |        1   | 8.2e-05 |       6 |
+ | perl -e1 (baseline) | 0.83                         | 4.1                | 16             |         5 |                      0 |        4.2 | 1.3e-05 |       7 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
