@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::CBlocks::Numeric;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -9,183 +9,183 @@ our $results = [
     [
       {
         dataset     => 316227,
-        errors      => 0.00028,
+        errors      => 0.00014,
         participant => "C::Blocks",
-        rate        => 6.1,
-        samples     => 7,
-        time        => 160,
+        rate        => 6.43,
+        samples     => 6,
+        time        => 155,
         vs_slowest  => 1,
       },
       {
         dataset     => 316227,
-        errors      => 0.00075,
+        errors      => 8.3e-05,
         participant => "perl",
-        rate        => 6.8,
+        rate        => 6.95,
         samples     => 6,
-        time        => 150,
-        vs_slowest  => 1.1,
+        time        => 144,
+        vs_slowest  => 1.08,
       },
       {
         dataset     => 100000,
-        errors      => 0.00089,
+        errors      => 3.3e-05,
         participant => "C::Blocks",
-        rate        => 20,
-        samples     => 7,
-        time        => 50,
-        vs_slowest  => 3,
+        rate        => 19.8,
+        samples     => 6,
+        time        => 50.6,
+        vs_slowest  => 3.07,
       },
       {
         dataset     => 100000,
-        errors      => 0.00069,
+        errors      => 3.2e-05,
         participant => "perl",
-        rate        => 20,
-        samples     => 6,
-        time        => 50,
-        vs_slowest  => 3,
+        rate        => 22.1,
+        samples     => 9,
+        time        => 45.3,
+        vs_slowest  => 3.43,
       },
       {
         dataset     => 31622,
-        errors      => 0.00023,
-        participant => "perl",
-        rate        => 70,
+        errors      => 2.9e-06,
+        participant => "C::Blocks",
+        rate        => 66.5,
         samples     => 6,
-        time        => 10,
-        vs_slowest  => 10,
+        time        => 15,
+        vs_slowest  => 10.3,
+      },
+      {
+        dataset     => 31622,
+        errors      => 2e-06,
+        participant => "perl",
+        rate        => 70.4,
+        samples     => 6,
+        time        => 14.2,
+        vs_slowest  => 10.9,
       },
       {
         dataset     => 10000,
-        errors      => 0.00036,
-        participant => "C::Blocks",
-        rate        => 100,
-        samples     => 10,
-        time        => 7,
-        vs_slowest  => 20,
-      },
-      {
-        dataset     => 10000,
-        errors      => 2.4e-06,
-        participant => "perl",
-        rate        => 219,
-        samples     => 6,
-        time        => 4.57,
-        vs_slowest  => 35.9,
-      },
-      {
-        dataset     => 3235,
-        errors      => 2e-05,
-        participant => "C::Blocks",
-        rate        => 400,
-        samples     => 9,
-        time        => 2.5,
-        vs_slowest  => 66,
-      },
-      {
-        dataset     => 3235,
-        errors      => 2.9e-07,
-        participant => "perl",
-        rate        => 654,
-        samples     => 6,
-        time        => 1.53,
-        vs_slowest  => 107,
-      },
-      {
-        dataset     => 1000,
-        errors      => 1.4e-05,
-        participant => "C::Blocks",
-        rate        => 1000,
-        samples     => 7,
-        time        => 0.9,
-        vs_slowest  => 200,
-      },
-      {
-        dataset     => 1000,
         errors      => 3.9e-07,
         participant => "perl",
-        rate        => 2290,
+        rate        => 133,
         samples     => 6,
-        time        => 0.436,
-        vs_slowest  => 376,
+        time        => 7.516,
+        vs_slowest  => 20.68,
       },
       {
-        dataset     => 31622,
-        errors      => 4.9e-07,
-        participant => "C::Blocks",
-        rate        => 2900,
+        dataset     => 3235,
+        errors      => 9.7e-08,
+        participant => "perl",
+        rate        => 683.8,
         samples     => 6,
-        time        => 0.34,
-        vs_slowest  => 480,
+        time        => 1.462,
+        vs_slowest  => 106.3,
+      },
+      {
+        dataset     => 1000,
+        errors      => 5.3e-11,
+        participant => "perl",
+        rate        => 2212.87,
+        samples     => 6,
+        time        => 0.451902,
+        vs_slowest  => 344,
       },
       {
         dataset     => 316,
-        errors      => 8.8e-07,
-        participant => "C::Blocks",
-        rate        => 5800,
+        errors      => 6.4e-11,
+        participant => "perl",
+        rate        => 6993.43,
         samples     => 6,
-        time        => 0.17,
-        vs_slowest  => 950,
+        time        => 0.142991,
+        vs_slowest  => 1087.16,
       },
       {
-        dataset     => 316,
-        errors      => 2.9e-07,
-        participant => "perl",
-        rate        => 7200,
-        samples     => 11,
-        time        => 0.14,
-        vs_slowest  => 1200,
+        dataset     => 10000,
+        errors      => 0,
+        participant => "C::Blocks",
+        rate        => 8480.48,
+        samples     => 6,
+        time        => 0.117918,
+        vs_slowest  => 1318.33,
       },
       {
         dataset     => 100,
-        errors      => 6.7e-11,
+        errors      => 0,
         participant => "C::Blocks",
-        rate        => 18539,
+        rate        => 20854.2,
         samples     => 6,
-        time        => 0.053939,
-        vs_slowest  => 3043.9,
+        time        => 0.0479519,
+        vs_slowest  => 3241.88,
       },
       {
         dataset     => 100,
-        errors      => 6.8e-08,
+        errors      => 2.3e-08,
         participant => "perl",
-        rate        => 23000,
+        rate        => 21400,
         samples     => 7,
-        time        => 0.044,
-        vs_slowest  => 3700,
+        time        => 0.0468,
+        vs_slowest  => 3320,
+      },
+      {
+        dataset     => 3235,
+        errors      => 2.1e-11,
+        participant => "C::Blocks",
+        rate        => 32577.3,
+        samples     => 6,
+        time        => 0.0306962,
+        vs_slowest  => 5064.28,
       },
       {
         dataset     => 31,
-        errors      => 6.2e-07,
+        errors      => 0,
         participant => "C::Blocks",
-        rate        => 30000,
-        samples     => 9,
-        time        => 0.03,
-        vs_slowest  => 5000,
+        rate        => 65280.9,
+        samples     => 6,
+        time        => 0.0153184,
+        vs_slowest  => 10148.2,
       },
       {
         dataset     => 31,
-        errors      => 5e-10,
+        errors      => 0,
         participant => "perl",
-        rate        => 65330,
+        rate        => 69735.4,
         samples     => 6,
-        time        => 0.01531,
-        vs_slowest  => 10730,
+        time        => 0.0143399,
+        vs_slowest  => 10840.7,
       },
       {
-        dataset     => 10,
-        errors      => 2.4e-08,
+        dataset     => 1000,
+        errors      => 0,
         participant => "C::Blocks",
-        rate        => 100000,
+        rate        => 103887,
         samples     => 6,
-        time        => 0.0096,
-        vs_slowest  => 17000,
+        time        => 0.0096258,
+        vs_slowest  => 16149.7,
       },
       {
         dataset     => 10,
-        errors      => 1.5e-08,
-        participant => "perl",
-        rate        => 190000,
+        errors      => 2.1e-11,
+        participant => "C::Blocks",
+        rate        => 202450,
         samples     => 6,
-        time        => 0.0053,
-        vs_slowest  => 31000,
+        time        => 0.0049396,
+        vs_slowest  => 31471,
+      },
+      {
+        dataset     => 10,
+        errors      => 1.1e-08,
+        participant => "perl",
+        rate        => 210000,
+        samples     => 7,
+        time        => 0.0047,
+        vs_slowest  => 33000,
+      },
+      {
+        dataset     => 316,
+        errors      => 3e-09,
+        participant => "C::Blocks",
+        rate        => 323000,
+        samples     => 6,
+        time        => 0.00309,
+        vs_slowest  => 50300,
       },
     ],
     {
@@ -308,7 +308,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2898.546,
+                                              speed                        => 2860.757,
                                               stepping                     => 4,
                                             },
                                             {
@@ -423,7 +423,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2600.937,
+                                              speed                        => "2770.250",
                                               stepping                     => 4,
                                             },
                                             {
@@ -538,7 +538,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2833.578,
+                                              speed                        => 2889.906,
                                               stepping                     => 4,
                                             },
                                             {
@@ -653,14 +653,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2600.007,
+                                              speed                        => 2600.226,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 3.99748682975769,
+      "func.elapsed_time"              => 3.88052892684937,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.034,
+                                            "__PACKAGE__" => 1.039,
                                             "Bencher::Scenario::CBlocks::Numeric" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "C::Blocks" => 0.41,
@@ -699,9 +699,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1485326981,
       "func.scenario_module_sha1sum"   => "34555f7b653c41978919236bc75dc8cb1e966f99",
       "func.scenario_module_sha256sum" => "8c295fdf37fb107618dd35936ef1a25ae2d854daecd797868ce1f7be61e2052b",
-      "func.time_end"                  => 1485327059.83891,
+      "func.time_end"                  => 1499087546.31095,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485327055.84142,
+      "func.time_start"                => 1499087542.43042,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
